team_abr_afl: Internal function to return team name abbreviation for AFL API
Description
Internal function to return team name abbreviation for AFL API
Usage
team_abr_afl(team, return_id = FALSE)
Arguments
- team
Team name
- return_id
Should we return the team ID used by the API instead of the abbreviation?